var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useCallback, useEffect, useState } from 'react';
import { v4 as uuidv4 } from 'uuid';
import { MAX_CHUNK_SIZE } from './consts';
const initialState = {
    showProgress: false,
    counter: 1,
    fileToBeUpload: null,
    beginingOfTheChunk: 0,
    endOfTheChunk: MAX_CHUNK_SIZE,
    progress: 0,
    fileGuid: '',
    originFileName: '',
    fileSize: 0,
    chunkCount: 0,
};
export const useFileUploader = ({ onUploadChunk, onUploadCompleted, chunkSize = MAX_CHUNK_SIZE, }) => {
    const [state, setState] = useState(initialState);
    const { counter, fileToBeUpload, beginingOfTheChunk, endOfTheChunk, progress, fileGuid, originFileName, fileSize, chunkCount, } = state;
    const handleFile = useCallback((_file) => {
        const _totalCount = _file.size % chunkSize == 0
            ? _file.size / chunkSize
            : Math.floor(_file.size / chunkSize) + 1;
        const _fileID = uuidv4() + '.' + _file.name.split('.').pop();
        setState(Object.assign(Object.assign({}, initialState), { progress: 0, fileSize: _file.size, chunkCount: _totalCount, fileGuid: _fileID, originFileName: _file.name, fileToBeUpload: _file }));
    }, [chunkSize]);
    const fileUpload = () => {
        if (fileToBeUpload && counter <= chunkCount) {
            const chunk = fileToBeUpload.slice(beginingOfTheChunk, endOfTheChunk);
            uploadChunk(chunk);
        }
    };
    const uploadChunk = useCallback((chunk) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            /*const response =*/ yield onUploadChunk({
                id: counter,
                fileName: fileGuid,
                chunk,
            });
            //const data = response.data;
            let progress;
            if (counter == chunkCount) {
                yield uploadCompleted({ fileGuid, originFileName });
                progress = 100;
            }
            else {
                progress = (counter / chunkCount) * 100;
            }
            setState(Object.assign(Object.assign({}, state), { beginingOfTheChunk: endOfTheChunk, endOfTheChunk: endOfTheChunk + chunkSize, progress, counter: counter + 1 }));
        }
        catch (error) {
            console.log('error', error);
        }
    }), [
        onUploadChunk,
        state,
        setState,
        chunkCount,
        fileGuid,
        originFileName,
        counter,
        chunkSize,
        beginingOfTheChunk,
        endOfTheChunk,
    ]);
    const uploadCompleted = useCallback(({ fileGuid, originFileName }) => __awaiter(void 0, void 0, void 0, function* () {
        /*const data =*/ yield onUploadCompleted({
            fileName: fileGuid,
            originFileName,
        });
    }), [onUploadCompleted]);
    useEffect(() => {
        if (fileSize > 0 && progress < 100) {
            fileUpload();
        }
    }, [fileToBeUpload, progress]);
    return {
        handleFile,
        fileToBeUpload,
        progress,
        reset() {
            setState(initialState);
        },
    };
};
